@@ -22,23 +22,25 @@ RUN_OBJ_JSON_PATH = 'json_path'
 RUN_OBJ_CSV_PATH = 'csv_path'
 RUN_OBJ_VISUAL_PATH = 'visual_path'
 
+# path for setting
+RUN_OBJ_MODEL_FILE_PATH = 'path'
 RUN_OBJ_MODEL_JSON_PATH = 'model_json_path'
 RUN_OBJ_VISUAL_CSV_PATH = 'visual_csv_path'
 RUN_OBJ_VISUAL_JSON_PATH = 'visual_json_path'
+RUN_OBJ_SHAP_JSON_PATH = 'shap_json_path'
 RUN_OBJ_BEST_MODEL_H5_PATH = 'save_best_model_h5_path'
 RUN_OBJ_BEST_MODEL_JSON_PATH = 'save_best_model_json_path'
 RUN_OBJ_BEST_MODEL_JOBLIB_PATH = 'save_best_model_joblib_path'
 RUN_OBJ_DATA_VERSION = 'data_version'
-RUN_OBJ_MODEL_FILE_PATH = 'path'
 
-##########deprecated###########
+# full path
 RUN_MODEL_JSON_PATH = 'model_json_full'
 RUN_MODEL_VISUAL_JSON_PATH = 'visual_json_full'
 RUN_MODEL_VISUAL_CSV_PATH = 'visual_csv_full'
+RUN_MODEL_SHAP_JSON_PATH = 'shap_json_full'
 RUN_MODEL_HDF5_PATH = 'save_model_hdf5'
 RUN_MODEL_HOME_PATH = 'home_path'
 RUN_RESULT_PATH = 'result_path'
-#####################
 
 TRUE_Y = 'True_y'
 
@@ -56,7 +58,6 @@ START_TIME = 'start_time'
 END_TIME = 'end_time'
 DELTA_TIME = 'delta_time'
 
-
 ENV_PROJECT_ID='LC_PROJECT_ID'
 ENV_WORKSPACE_ID='LC_WORKSPACE_ID'
 ENV_EXPERIMENT_ID='LC_EXPERIMENT_ID'
@@ -66,7 +67,7 @@ ENV_LANGUAGE_ID = 'LC_LANGUAGE_ID'
 ENV_JUPYTER_WORKSPACE = '/home/notebook/.jupyter/lab/workspaces'
 ENV_JUPYTER__HOME_DIR = '/home/work'
 
-# BACK_END_API_URL = 'api.accu'
-BACK_END_API_URL = 'localhost'
-BACK_END_API_PORT = '8080'
 BACK_END_API_URI = ''
+BACK_END_API_URL = 'modeler-api.accu'
+BACK_END_API_PORT = '8080'
+
