@@ -143,11 +143,10 @@ def _parse_selected_metrics(run_meta):
     for key in metric_keys:
         values.append(str(selected_metrics[key]))
         timestamp.append(str(count))
-        steps.append(str(count))
+        steps.append(key)
         count += 1
 
     result_dict['metrics'].append({
-                                   'key': key,
                                    'values': values,
                                    'timestamp': timestamp,
                                    'steps': steps})
@@ -156,7 +155,7 @@ def _parse_selected_metrics(run_meta):
 
     for item in metrics:
         metric = LcMetric(
-                key=item['key'],
+                key=SELECTED_METRICS,
                 values=item['values'],
                 timestamp=item['timestamp'],
                 steps=item['steps']
