@@ -2,7 +2,6 @@ from __future__ import print_function
 import os
 import sys
 import json
-from pathlib import Path
 from Accuinsight.modeler.core.LcConst import LcConst
 
 _BASH_RC_PATH = '/home/notebook/.bashrc'
@@ -28,7 +27,6 @@ def get_os_env(env_type='LC', env_path=None, env_file=None):
                 key, value = line.split('=')
                 if key is not None:
                     if _ENV_PREFIX in key:
-                        key = key
                         value = value.rstrip()
                         env_value.setdefault(key, value)
 
